#!/bin/sh
# Copyright 2001, Compaq Computer Corporation.  All rights reserved.
# Software Patch for Compaq Foundation Agents for Linux
# Version 1.0.0
#
if [ `id -un` != "root" ]; then
  echo "ERROR: this script can be executed by \"root\" only!"
  exit 1
fi

SPNUM="sp17928"
TMPROOT="/var/spool/compaq/foundation/tmp"
if [ ! -d $TMPROOT/$SPNUM ]; then
  mkdir -p $TMPROOT/$SPNUM
  chmod go-rwx $TMPROOT
fi

INFOFILE="$TMPROOT/$SPNUM/$SPNUM.info"
OLDFILE="/opt/compaq/foundation/bin/libcpqhmmo.so"
NEWFILE="libcpqhmmo.so"
NEWFILEMD5="6f48782f2286af3df27598106a74b1de"
DIR=`dirname $0`
[ -z "$DIR" ] && DIR="."

echo "" >> $INFOFILE
echo "###############################################################" >> $INFOFILE
echo "# `date`: $0 started!" >>$INFOFILE

if [ `id -un` != "root" ]; then
  echo "ERROR: this script can be executed by \"root\" only!"
  echo "ERROR: this script can be executed by \"root\" only!" >>$INFOFILE
  echo "# `date`: Exiting $0!" >>$INFOFILE
  exit 1
fi

# Verify new file
if [ -x /usr/bin/md5sum ]; then
  if [ ! -f $DIR/$NEWFILE ]; then
    echo "ERROR: $DIR/$NEWFILE does not exist!"
    echo "# ERROR: $DIR/$NEWFILE does not exist!" >>$INFOFILE
    echo "# `date`: Exiting $0!" >>$INFOFILE
    exit 1
  fi
  echo "$NEWFILEMD5  $DIR/$NEWFILE" | /usr/bin/md5sum -c >>$INFOFILE 2>&1
  if [  "$?" != "0" ]; then
    echo "ERROR: $DIR/$NEWFILE has incorrect md5 checksum!"
    echo "# ERROR: $DIR/$NEWFILE has incorrect md5 checksum!" >>$INFOFILE
    echo "# `date`: Exiting $0!" >>$INFOFILE
    exit 1
  fi
fi

# Check for the Red Hat Linux 6.2
grep "Red Hat.* 6\.2 " /etc/issue >/dev/null 2>&1
if [ "$?" != 0 ]; then
  echo "ERROR: Only Red Hat Linux release 6.2 is supported!"
  echo "# ERROR: Only Red Hat Linux release 6.2 is supported!" >>$INFOFILE
  echo "# `date`: Exiting $0!" >>$INFOFILE
  exit 1
fi

# Check for the verion number of cmafdtn
CMAFDTN=`rpm -q cmafdtn 2>/dev/null`
if [ "$?" != 0 -o -z "$CMAFDTN" ]; then
  echo "ERROR: Compaq Foundation Agents (cmafdtn) is NOT installed!"
  echo "# ERROR: Compaq Foundation Agents (cmafdtn) is NOT installed!" >>$INFOFILE
  echo "# `date`: Exiting $0!" >>$INFOFILE
  exit 1
fi

echo $CMAFDTN | egrep 'cmafdtn-4\.90-|cmafdtn-4\.90b-|cmafdtn-5\.00-' >/dev/null 2>&1

if [ "$?" != 0 ]; then
  echo "ERROR: Only Compaq Foundation Agents (cmafdtn) versions 4.90, 4.90b and 5.00 are supported!"
  echo "ERROR: $CMAFDTN is currently installed on your system!"
  echo "# ERROR: Only Compaq Foundation Agents (cmafdtn) versions 4.90, 4.90b and 5.00 are supported!" >>$INFOFILE
  echo "# ERROR: $CMAFDTN is currently installed on your system!" >>$INFOFILE
  echo "# `date`: Exiting $0!" >>$INFOFILE
  exit 1
fi

# Verify existing file
if [ -x /usr/bin/md5sum ]; then
  if [ -f $OLDFILE ]; then
    echo "$NEWFILEMD5  $OLDFILE" | /usr/bin/md5sum -c >>$INFOFILE 2>&1
    if [  "$?" = "0" ]; then
      echo "$OLDFILE already matches md5 checksum! No action is needed!"
      echo "# INFO: $OLDFILE already matches md5 checksum! No action is needed!" >>$INFOFILE
      echo "# `date`: Exiting $0!" >>$INFOFILE
      exit 1
    fi
  fi
fi

# Now we can do it!
# Is Web agent running?
WEBAGENT=`pidof cmawebd`
if [ ! -z "$WEBAGENT" ]; then
  echo "Stopping Web agent (cmawebd)!"
  echo "# INFO: Stopping Web agent (cmawebd)!" >>$INFOFILE
  /etc/rc.d/init.d/cmafdtn stop cmawebd >>$INFOFILE 2>&1
fi

cp -pf $OLDFILE $TMPROOT/$SPNUM
if [ "$?" != "0" ]; then
  echo "ERROR: Saving $OLDFILE to $TMPROOT/$SPNUM directory failed!"
  echo "# ERROR: Saving $OLDFILE to $TMPROOT/$SPNUM directory failed!" >>$INFOFILE
  echo "# `date`: Exiting $0!" >>$INFOFILE
  exit 1
else
  echo "Saved $OLDFILE to $TMPROOT/$SPNUM directory!"
  echo "# INFO: Saved $OLDFILE to $TMPROOT/$SPNUM directory!" >>$INFOFILE
fi

chmod +w $OLDFILE
cp -pf $DIR/$NEWFILE $OLDFILE
if [ "$?" != "0" ]; then
  echo "ERROR: Copying $DIR/$NEWFILE to $OLDFILE failed!"
  echo "# ERROR: Copying $DIR/$NEWFILE to $OLDFILE failed!" >>$INFOFILE
  echo "# `date`: Exiting $0!" >>$INFOFILE
  exit 1
else
  chmod 500 $OLDFILE
  echo "Copied $DIR/$NEWFILE to $OLDFILE!"
  echo "# INFO: Copied $DIR/$NEWFILE to $OLDFILE!" >>$INFOFILE
fi
chmod -w $OLDFILE

if [ ! -z "$WEBAGENT" ]; then
  echo "Starting Web agent (cmawebd)!"
  echo "# INFO: Starting Web agent (cmawebd)!" >>$INFOFILE
  /etc/rc.d/init.d/cmafdtn start cmawebd >>$INFOFILE 2>&1
fi

echo "============================================================="
echo "$0 completed successfully!"
echo "See $INFOFILE for more information!"
echo "============================================================="
echo "# $0 completed successfully!" >>$INFOFILE
exit 0
